Coverage for project/travis.py: 0%

# Coverage for project/travis.py : 0%

## 8 statements 0 run 8 missing 0 excluded 0 partial

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 from .base_settings import * # noqa

2 import sys

3

4# SECURITY WARNING: keep the secret key used in production secret!

5 SECRET_KEY = '294xJnzB5UkIJksvV8vU0D4n16MfEw46mJCKn6l7' # noqa

6

7# SECURITY WARNING: don't run with debug turned on in production!

8 DEBUG = True

9

10 ALLOWED_HOSTS = ['localhost', '127.0.0.1']

11

12# Database

13# https://docs.djangoproject.com/en/3.0/ref/settings/#databases

14

15 DATABASES = {

16 'default': {

17 'ENGINE': 'django.db.backends.postgresql_psycopg2',

18 'NAME': 'django_jutil',

19 'USER': 'postgres',

20 'PASSWORD': '', # noqa

21 'HOST': 'localhost',

22 'PORT': 5432,

23 'CONN_MAX_AGE': 180,

24 }

25}

26

27# IP stack (IP country code)

28 IPSTACK_TOKEN = ''

29

30# Logging

31 LOGGING = {

32 'version': 1,

33 'disable_existing_loggers': False,

34 'filters': {

35 'ndebug': {

36 '()': 'django.utils.log.RequireDebugFalse',

37 },

38 },

39 'formatters': {

40 'verbose': {

41 'format' : "[%(asctime)s] %(levelname)s [%(name)s:%(lineno)s] %(message)s",

42 'datefmt' : "%Y-%m-%d %H:%M:%S"

43 },

44 'simple': {

45 'format': '%(levelname)s %(message)s'

46 },

47 },

48 'handlers': {

49 'console': {

50 'class': 'logging.StreamHandler',

51 'stream': sys.stdout,

52 }

53 },

54 'loggers': {

55 'jutil': {

56 'handlers': ['console'],

57 'level': 'DEBUG',

58 },

59 'django': {

60 'handlers': ['console'],

61 'level': 'WARNING',

62 },

63 }

64}